"""Test module for streamplots."""

# Disclaimer
# ----------
#
# Copyright (C) 2021 Helmholtz-Zentrum Hereon
# Copyright (C) 2020-2021 Helmholtz-Zentrum Geesthacht
# Copyright (C) 2016-2021 University of Lausanne
#
# This file is part of psy-simple and is released under the GNU LGPL-3.O license.
# See COPYING and COPYING.LESSER in the root of the repository for full
# licensing details.
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License version 3.0 as
# published by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU LGPL-3.0 license for more details.
#
# You should have received a copy of the GNU LGPL-3.0 license
# along with this program.  If not, see <https://www.gnu.org/licenses/>.

import os

from psyplot import rcParams
from psy_simple.plotters import SimpleVectorPlotter

import _base_testing as bt
import test_vector as tv


class SimpleStreamVectorPlotterTest(tv.SimpleVectorPlotterTest):
    """Test case for stream plot of
    :class:`psy_simple.plotters.SimpleVectorPlotter`
    """

    @classmethod
    def setUpClass(cls):
        plotter = SimpleVectorPlotter()
        rcParams[plotter.plot.default_key] = "stream"
        return super(SimpleStreamVectorPlotterTest, cls).setUpClass()

    def get_ref_file(self, identifier):
        return super(SimpleStreamVectorPlotterTest, self).get_ref_file(
            identifier + "_stream"
        )

    def ref_arrowsize(self, *args):
        """Create reference file for arrowsize formatoption.

        Create reference file for
        :attr:`~psy_simple.plotters.SimpleVectorPlotter.arrowsize` (and others)
        formatoption"""
        sp = self.plot(arrowsize=2.0)
        sp.export(os.path.join(bt.ref_dir, self.get_ref_file("arrowsize")))

    def ref_arrowstyle(self, *args):
        """Create reference file for arrowstyle formatoption.

        Create reference file for
        :attr:`~psy_simple.plotters.SimpleVectorPlotter.arrowstyle` (and
        others) formatoption"""
        sp = self.plot(arrowsize=2.0, arrowstyle="fancy")
        sp.export(os.path.join(bt.ref_dir, self.get_ref_file("arrowstyle")))

    def test_arrowsize(self, *args):
        """Test arrowsize formatoption"""
        self.update(arrowsize=2.0)
        self.compare_figures(next(iter(args), self.get_ref_file("arrowsize")))

    def test_arrowstyle(self, *args):
        """Test arrowstyle formatoption"""
        self.update(arrowsize=2.0, arrowstyle="fancy")
        self.compare_figures(next(iter(args), self.get_ref_file("arrowstyle")))

    def ref_density(self, *args):
        """Create reference file for density formatoption.

        Create reference file for
        :attr:`~psy_simple.plotters.SimpleVectorPlotter.density` (and others)
        formatoption"""
        sp = self.plot(density=0.5)
        sp.export(os.path.join(bt.ref_dir, self.get_ref_file("density")))

    def test_density(self, *args):
        """Test density formatoption"""
        self.update(density=0.5)
        self.compare_figures(next(iter(args), self.get_ref_file("density")))
